function [GT,IND]=GjFULL(N, S, Ljjs_sjk3D, alpha_tilde_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, LABOR)
% this function computes gains from trade Gj
% Labor: 1 -- if only labor in fixed costs
% Labor: 0 -- if intermediate goods are used in fixed costs
% IND -- indicators if the non-negativity conditions are satisfied (1-yes, 0-no)

if LABOR==1 % fixed costs use LABOR ONLY 
    sigma_sjk3D=(epsilon_sjk3D+eta_sjk3D+1)./(eta_sjk3D+1);
    alpha_sjk3D=alpha_tilde_sjk3D./(1-delta_sjk3D./sigma_sjk3D);
    mu_sjk3D=alpha_sjk3D.*(epsilon_sjk3D+(1-delta_sjk3D).*(1+eta_sjk3D))./(epsilon_sjk3D+1+eta_sjk3D); % mu_j,ks in (s,j,k)
    %ERR=mu_sjk3D-alpha_tilde_sjk3D;
    
    %.... System of equations for eA/vA (X): X=B+A*X 
    B=reshape(betajs_sjk3D(:,:,1),S*N,1);
    AUXmu=kron(eye(N),ones(S));
    MU=reshape(permute(mu_sjk3D,[3 1 2]),S,S*N);
    MU2D=kron(ones(N,1),MU);
    A=AUXmu.*MU2D;
    X=(eye(N*S)-A)\B;
    eAvA_sjk3D=repmat(reshape(X,S,N),[1 1 S]);    % eA/vA_j,s in (s,j,k);
    %....
    
    vjs_tilde_sjk3D=vj_sjk3D.*eAvA_sjk3D;
    AUX1=Ljjs_sjk3D.*((rjs_sjk3D./vjs_tilde_sjk3D).*(ejs_sjk3D.*rhoj_sjk3D./vjs_tilde_sjk3D).^(eta_sjk3D)).^(-delta_sjk3D);
    betajk_sjk3D=permute(betajs_sjk3D,[3 2 1]);
    
    alpha_ksj3D=permute(alpha_sjk3D,[3 1 2]);
    a_ksj3D=zeros(S,S,N); %matrix for (I-A')^(-1)
    for j=1:N
        a_ksj3D(:,:,j)=(eye(S)-alpha_ksj3D(:,:,j)')^(-1); 
    end
    a_sjk3D=permute(a_ksj3D,[2 3 1]);
    AUX2=betajk_sjk3D.*a_sjk3D./epsilon_sjk3D;
    GT3D=1-prod(prod(AUX1.^AUX2,3),1);
    GT=reshape(GT3D,N,1);
    IND0=(sum(alpha_sjk3D,3)>1);    % indicates cells with errors
    IND=(sum(IND0)==0); % "1" if no sectors in a cuntry are problematic
    IND=IND';
    
else%       fixed costs use INTERMEDIATE goods
    
    alpha_sjk3D=alpha_tilde_sjk3D;
    mu_sjk3D=alpha_sjk3D; % mu_j,ks in (s,j,k)
    
    
    %.... System of equations for eA/vA (X): X=B+A*X 
    B=reshape(betajs_sjk3D(:,:,1),S*N,1);
    AUXmu=kron(eye(N),ones(S));
    MU=reshape(permute(mu_sjk3D,[3 1 2]),S,S*N);
    MU2D=kron(ones(N,1),MU);
    A=AUXmu.*MU2D;
    X=(eye(N*S)-A)\B;
    eAvA_sjk3D=repmat(reshape(X,S,N),[1 1 S]);    % eA/vA_j,s in (s,j,k);
    %....
    
    IND=zeros(N,1);
    vjs_tilde_sjk3D=vj_sjk3D.*eAvA_sjk3D;
    AUX1=Ljjs_sjk3D.*((rjs_sjk3D./vjs_tilde_sjk3D).*(ejs_sjk3D.*rhoj_sjk3D./vjs_tilde_sjk3D).^(eta_sjk3D)).^(-delta_sjk3D);
    betajk_sjk3D=permute(betajs_sjk3D,[3 2 1]);
    alpha_p_sjk3D=alpha_sjk3D.*(1+delta_sjk3D.*(1+eta_sjk3D)./epsilon_sjk3D); % alpha_sjk prime
    alpha_p_ksj3D=permute(alpha_p_sjk3D,[3 1 2]);
    a_p_ksj3D=zeros(S,S,N); %matrix for (I-A')^(-1)
    for j=1:N
        a_p_ksj3D(:,:,j)=(eye(S)-alpha_p_ksj3D(:,:,j)')^(-1); 
        IND(j,1)=isempty(find(a_p_ksj3D(:,:,j)<0,1));
    end
    a_p_sjk3D=permute(a_p_ksj3D,[2 3 1]);
    AUX2=betajk_sjk3D.*a_p_sjk3D./epsilon_sjk3D;
    GT3D=1-prod(prod(AUX1.^AUX2,3),1);
    GT=reshape(GT3D,N,1); 

end

end