%==========================================================================
% Step 03: this file solves the DEK exercise for the zero trade deficit
% (D=0)
%==========================================================================
clear all;

%============================ READ THE DATA ===============================
% Load data from Step_01_... All variables in the loaded data are supposed to be "cubes" NxNxS: (i,j,s);
load Step_01_WIOD_AGG_no_INT.mat;

%============================== SET SHOCKS ================================
tauijs_h3D=ones(N,N,S);
tijs3D=zeros(N,N,S);
tijs_p3D=zeros(N,N,S);
Dj_h3D=zeros(N,N,S);    % trade deficits are reduced to zero

%============================= SET PARAMETERS =============================
X0=ones(N,1);
yis3D=Yis3D./Yi3D;
mu=1;

%============================= SOLVE THE MODEL ============================
syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
options = optimset('Display','iter','Algorithm','trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100000,'TolFun',1e-10,'TolX',1e-10);
[x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
max(abs(fval_fsolve))

% Save the solution w^i as a "cube"
wi_h=x_fsolve((end-N+1):end,1);
wi_h3D=repmat(wi_h,[1 N S]);

% Compute yis_h3D using wi_h
wj_h3D=permute(wi_h3D,[2 1 3]);
Yj3D=permute(Yi3D,[2 1 3]);
phiijs3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);  % ratio of shipping costs (trans+tariffs): t'/t
AUX0=Lijs3D.*((phiijs3D.*wi_h3D).^(-epsilon_s3D));
AUX1=repmat(sum(AUX0,1),[N 1 1]);
AUX2=AUX0./AUX1;    %Lijs^ * Lijs
kj_p3D=1./(1-repmat(sum(sum(AUX2.*betajs3D.*tijs_p3D./(1+tijs_p3D),3),1),[N 1 S])); % kappa_j'
AUX3=betajs3D.*kj_p3D.*(wj_h3D.*Yj3D+Dj_h3D.*Dj3D.*(wj_h3D.^mu)); %Ejs^ * Ejs
yis_h3D=repmat(sum(AUX2.*AUX3./(1+tijs_p3D),2),[1 N 1])./(wi_h3D.*Yi3D.*yis3D);
nan_idx=find(isnan(yis_h3D));
yis_h3D(nan_idx)=1; % replace all yis_h3D=NaN with yis_h3D=1 since all NaNs are coming from sectors with zero output

%=========================== SAVE THE SOLUTION ============================
save Step_03_DATA_D0.mat N S mu sigma_s3D wi_h3D yis_h3D Lijs3D epsilon_s3D

