%==========================================================================
% Step 5: this file builds Figure 1: welfare implications of unilat. tariff 
%==========================================================================
clear all;

% ------------- Load the zero-deficit data (see Step_03, ..._04 for details)
load Step_04_DATA_D0_PC_extd.mat;
Dj3D=Dj_new3D;      %Lijs3D=Lijs_new3D;
yis3D=yis_new3D;    Yi3D=Yi_new3D;      Yis3D=Yis_new3D;
Xijs3D=Xijs_new3D;

% ------------- Aggregate all sectors into: S=35 --> S=1
S=1;
Yi3D=Yi3D(:,:,1);       Dj3D=Dj3D(:,:,1);
Xij2D=sum(Xijs3D,3);    Xj2D=repmat(sum(Xij2D,1),[N 1]);    Lijs3D=Xij2D./Xj2D;
betajs3D=ones(N,N,S);   epsilon_s3D=5*ones(N,N,S);          sigma_s3D=epsilon_s3D+1;
consjs3D=ones(N,N,S);

% ------------- Set other parameters
% Initial and new tariffs
tijs3D=zeros(N,N,S);
tijs_p3D=zeros(N,N,S);

% Changes in transportation costs
tau_h=1;    
tauij_h2D=tau_h*ones(N)+(1-tau_h)*eye(N);   
tauijs_h3D=repmat(tauij_h2D,[1 1 S]);

% Other parameters
Dj_h3D=zeros(N,N,S);
X0=ones(N,1);
mu=1;

NN=100; % number of steps for tariffs
WELFARE_US_OPT_TRF_D0=zeros(NN,5);
WELFARE_FR_OPT_TRF_D0=zeros(NN,5);
WELFARE_PT_OPT_TRF_D0=zeros(NN,5);
WELFARE_IR_OPT_TRF_D0=zeros(NN,5);

% ------------- Compute optimal unilateral tariffs
%matlabpool('open',2);
for i=1:NN
    % *** US ***
    tijs_p3D=zeros(N,N,S);  tijs_p3D(:,33,:)=i/100; tijs_p3D(33,33,:)=0;
    syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
    [x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
    max(abs(fval_fsolve))  % check the accuracy of solution
    wi_h=abs(x_fsolve((end-N+1):end,1));
    wi_h3D=repmat(wi_h,[1 N S]);
    [wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    WELFARE_US_OPT_TRF_D0(i,:)=[i, wj_h(33,1), Pj_h(33,1), Ej_h(33,1), Cj_h(33,1)];

    % *** FR ***
    tijs_p3D=zeros(N,N,S);  tijs_p3D(:,12,:)=i/100; tijs_p3D(12,12,:)=0;
    syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
    [x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
    max(abs(fval_fsolve))  % check the accuracy of solution
    wi_h=abs(x_fsolve((end-N+1):end,1));
    wi_h3D=repmat(wi_h,[1 N S]);
    [wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    WELFARE_FR_OPT_TRF_D0(i,:)=[i, wj_h(12,1), Pj_h(12,1), Ej_h(12,1), Cj_h(12,1)];

    % *** PT ***
    tijs_p3D=zeros(N,N,S);  tijs_p3D(:,25,:)=i/100; tijs_p3D(25,25,:)=0;
    syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
    [x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
    max(abs(fval_fsolve))  % check the accuracy of solution
    wi_h=abs(x_fsolve((end-N+1):end,1));
    wi_h3D=repmat(wi_h,[1 N S]);
    [wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    WELFARE_PT_OPT_TRF_D0(i,:)=[i, wj_h(25,1), Pj_h(25,1), Ej_h(25,1), Cj_h(25,1)];

    % *** IR ***
    tijs_p3D=zeros(N,N,S);  tijs_p3D(:,18,:)=i/100; tijs_p3D(18,18,:)=0;
    syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
    [x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
    max(abs(fval_fsolve))  % check the accuracy of solution
    wi_h=abs(x_fsolve((end-N+1):end,1));
    wi_h3D=repmat(wi_h,[1 N S]);
    [wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    WELFARE_IR_OPT_TRF_D0(i,:)=[i, wj_h(18,1), Pj_h(18,1), Ej_h(18,1), Cj_h(18,1)];
end
%matlabpool close;

save FINAL_OPT_TRF_US_FR_PT_IR_FIG1.mat WELFARE*;

% ------------- Plot the result, Cj^
x=WELFARE_US_OPT_TRF_D0(:,1);
y1=WELFARE_US_OPT_TRF_D0(:,5);
y2=WELFARE_FR_OPT_TRF_D0(:,5);
y3=WELFARE_PT_OPT_TRF_D0(:,5);
y4=WELFARE_IR_OPT_TRF_D0(:,5);
%Z=[x,y1,y2,y3,y4];
f=figure();
%plot(x,y1,'-',x,y2,':',x,y3,'-.',x,y4,'--','linewidth', 2); 
plot(x,y1,x,y2,x,y3,x,y4,'linewidth', 1.5); 
grid('on');
%title('Figure 1: Optimal unilateral tariffs for one-sector model'); 
xlabel('Tariff, %'); 
ylabel('Welfare changes relative to 0% tariff regime');
legend ('USA','France','Portugal','Ireland');
saveas(f,'Figure_1.eps','eps2c');
