%==========================================================================
% Step 6: this step computes the welfare implications of US tariff dispers
%==========================================================================
clear all;

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_04_DATA_D0_PC.mat
Dj3D=Dj_new3D;
Lijs3D=Lijs_new3D;
Yi3D=Yi_new3D;
yis3D=yis_new3D;

%============================== SET SHOCKS ================================
tauijs_h3D=ones(N,N,S);
tijs3D=zeros(N,N,S);
tijs_p3D=zeros(N,N,S);
Dj_h3D=zeros(N,N,S);    % trade deficits are reduced to zero

%============================= SET PARAMETERS =============================
X0=ones(N,1);
mu=1;

%============================= SOLVE THE MODEL ============================
options = optimset('Display','iter','Algorithm','trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100000,'TolFun',1e-10,'TolX',1e-10);
TT=2;
step_t=0.005;
t_p=0:step_t:TT;
RESULT1=zeros(length(t_p),2);   % US welfare changes due to introduction of a uniform tariff
for i=1:1:length(t_p)
    tijs_p3D(:,33,:)=t_p(i);   tijs_p3D(33,33,:)=0;
    syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    [x_fsolve]=fsolve(syst, X0, options);
    wi_h=abs(x_fsolve((end-N+1):end,1));            wi_h3D=repmat(wi_h,[1 N S]);
    % compute the welfare implications
    [~, ~, ~, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
    RESULT1(i,:)=[t_p(i),Cj_h(33)];    
end

NN=1000;
tus=[0.4]';    
Cus1=zeros(NN,length(tus));
for j=1:length(tus) % loop for average taxes
    for i=1:NN  % loop for simulation of random tariffs dispersed around mean tus
        tp=tus(j)*(1+0.5*(-1+2*round(rand(S,1))));
        tp3D=repmat(reshape(tp,1,1,S),[N 1 1]);
        tijs_p3D(:,33,:)=tp3D;   tijs_p3D(33,33,:)=0;
        syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
        [x_fsolve]=fsolve(syst, X0, options);
        wi_h=abs(x_fsolve((end-N+1):end,1));            wi_h3D=repmat(wi_h,[1 N S]);
        % compute the welfare implications
        [~, ~, ~, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
        Cus1(i,j)=Cj_h(33);     
    end
end
Cus1=[tus,(mean(Cus1))'];    % Cus1^

save Step_6.mat RESULT1 Cus1
%load Step_6.mat
f=figure;
plot(100*RESULT1(:,1),RESULT1(:,2),'b-',100*Cus1(:,1),Cus1(:,2),'ro','linewidth',1.5);
ymin=ylim;
grid('on');
xlabel('US tariff, %');
ylabel('Welfare changes relative to 0% tariff regime');
legend('Uniform US tariff','Heterogeneous US tariffs around 40% mean');
tmin=find(RESULT1(:,2)>Cus1(:,2),1,'first');
tmax=find(RESULT1(:,2)>Cus1(:,2),1,'last');
line([100*RESULT1(tmin,1), 100*RESULT1(tmax,1)],[Cus1(:,2),Cus1(:,2)],'linewidth',1,'linestyle','--');
line([100*RESULT1(tmin,1), 100*RESULT1(tmin,1)],[ymin(1),Cus1(:,2)],'linewidth',1,'linestyle','--');
line([100*RESULT1(tmax,1), 100*RESULT1(tmax,1)],[ymin(1),Cus1(:,2)],'linewidth',1,'linestyle','--');
text(100*RESULT1(tmin,1),mean(RESULT1(:,2)),'\leftarrow 8.5%');
text(100*RESULT1(tmax,1),mean(RESULT1(:,2)),'\leftarrow 69%');
saveas(f,'Figure_2.eps', 'eps2c');



