%==========================================================================
% Step 8: builds the GT graph for different gammas under CES preferences
%==========================================================================
clear all;

%============================ READ THE DATA ===============================
% Load data from Step_01_...m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_01_WIOD_AGG_no_INT.mat

%================== COMPUTE AUXILIARY MATRICES AND CUBES ==================
idx=find(eye(N));
Xijs2D=reshape(Xijs3D,N*N,S);	% i,s
Xiis2D=Xijs2D(idx,:);	% Xii,s in (i,s)
Xjjs3D=permute(repmat(Xiis2D,[1 1 N]),[3 1 2]);	% Xjj,s in (i,j,s)
Xjj3D=repmat(sum(Xjjs3D,3),[1 1 S]);	% Xjj in (i,j,s)
Xj3D=repmat(sum(sum(Xijs3D,3),1),[N 1 S]);	% Xj in (i,j,s)
Ljj3D=Xjj3D./Xj3D;	% lambda_jj
Ljjs3D=Xjjs3D./Xjs3D;	% lambda_jj,s in (i,j,s)
gamma=[0.01:0.01:0.99,1.01:0.01:8];
GT=zeros(N,length(gamma));  %matrix for storing GTs

%======================== COMPUTE GAINS FROM TRADE ========================
for i=1:length(gamma)
    gamma3D=gamma(i)*ones(N,N,S);
    GTi=1-(repmat(sum(consjs3D.*(Ljjs3D).^((gamma3D-1)./epsilon_s3D),3),[1 1 S])).^(1./(gamma3D-1));
    GT(:,i)=reshape(GTi(1,:,1),N,1);
end
AVG=mean(GT);
GT=[GT;AVG];

%===================== BUILD A GRAPH, SAVE THE RESULTS ====================
dlmwrite('Figure_4.csv',[gamma;GT]);
f=figure;
plot(gamma, GT(5,:)*100, gamma, GT(8,:)*100, gamma, GT(12,:)*100, gamma, GT(20,:)*100, gamma, GT(33,:)*100, gamma, GT(35,:)*100, 'LineWidth', 1.5); % rows in GT-matrix correspond to countries
grid on; 
xlabel('Elasticity of substitution across sectors, \gamma'); 
ylabel('Gains from trade, %'); 
legend('Canada','Germany','France','Japan','USA','Average for the World'); 
saveas(f,'Figure_4.eps','eps2c');

