%==========================================================================
% Step 9: computes gains from trade (Table 1)
%==========================================================================
clear all;

% Load the data from Step_01_...m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_01_WIOD_AGG_with_INT.mat


%================== COMPUTE AUXILIARY MATRICES AND CUBES ==================
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)

alpha_data_sjk3D=alpha_tilde_sjk3D;
alpha_data_sj3D=repmat(sum(alpha_data_sjk3D,3),[1 1 S]);

alpha_tilde_sjk3D=alpha_tilde_sj3D.*ejk_sjk3D;
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);

alpha_sjk3D=alpha_tilde_sjk3D;
alpha_sj3D=alpha_tilde_sj3D;
Yj_sjk3D=repmat(Yj3D(1,:,1),[S 1 S]);   % Yj in (s,j,k)
Dj_sjk3D=repmat(Dj3D(1,:,1),[S 1 S]);   % Dj in (s,j,k)
Xjs_sjk3D=permute(repmat(Xjs3D(1,:,:),[S 1 1]),[3 2 1]);    % Xjs in (s,j,k)
Rjs_sjk3D=permute(repmat(Ris3D(:,1,:),[1 S 1]),[3 1 2]);      % Rjs in (s,j,k)
Rj_sjk3D=repmat(Rj3D(1,:,1),[S 1 S]);   % Rj in (s,j,k)
Ejs_sjk3D=Xjs_sjk3D;
Ej_sjk3D=repmat(sum(Ejs_sjk3D,1),[S 1 1]);
rhoj_sjk3D=Rj_sjk3D./(Rj_sjk3D+Dj_sjk3D);
rho1_sjk3D=ones(S,N,S);
ejs_sjk3D=Ejs_sjk3D./Ej_sjk3D;  %e_js in (s,j,k)
rjs_sjk3D=Rjs_sjk3D./Rj_sjk3D;
vj_sjk3D=Yj_sjk3D./Rj_sjk3D;

idx=find(eye(N));
Xijs2D=reshape(Xijs3D,N*N,S);	% i,s
Xiis2D=Xijs2D(idx,:);	% Xii,s in (i,s)
Xjjs3D=permute(repmat(Xiis2D,[1 1 N]),[3 1 2]);	% Xjj,s in (i,j,s)
Xjj3D=repmat(sum(Xjjs3D,3),[1 1 S]);		% Xjj in (i,j,s)
Xj3D=repmat(sum(sum(Xijs3D,3),1),[N 1 S]);	% Xj in (i,j,s)
Ljj3D=Xjj3D./Xj3D;      % lambda_jj
Ljjs3D=Xjjs3D./Xjs3D;	% lambda_jj,s in (i,j,s)

betajk_sjk3D=repmat(betajs3D(1,:,:),[S 1 1]);  % beta_jk in (s,j,k)
epsilon_sjk3D=repmat(reshape(epsilon_s3D(1,1,:),S,1),[1 N S]);	% epsilon_s in (s,j,k)
Ljjs_sjk3D=permute(repmat(Ljjs3D(1,:,:),[S 1 1]),[3 2 1]);		% Ljjs in (s,j,k)
betajs_sjk3D=permute(repmat(betajs3D(1,:,:),[S,1,1]),[3 2 1]);


%======================== COMPUTE GAINS FROM TRADE ========================

%=== GT1 ================================
epsilon=5;
GT1j3D=1-Ljj3D.^(1/epsilon);
GT1=reshape(GT1j3D(1,:,1),N,1);

%=== GT2 ================================
GT2j3D=1-repmat(prod(Ljjs3D.^(betajs3D./epsilon_s3D),3),[1 1 S]);
GT2=reshape(GT2j3D(1,:,1),N,1);

%=== GT3 - A ============================
delta_sjk3D=ones(S,N,S);    delta_sjk3D(16:end,:,:)=0;
eta_sjk3D=zeros(S,N,S);
GT3Aj3D=1-repmat(prod((Ljjs_sjk3D.*(rjs_sjk3D.*(rhoj_sjk3D.^eta_sjk3D)./ejs_sjk3D).^(-delta_sjk3D)).^(betajs_sjk3D./epsilon_sjk3D),1),[S 1 1]);
GT3A=reshape(GT3Aj3D(1,:,1),N,1);

%=== GT4 - alphas from data =============
delta_sjk3D=zeros(S,N,S);	
eta_sjk3D=zeros(S,N,S);
[GT4aLAB,IND4LAB]=GjFULL(N, S, Ljjs_sjk3D, alpha_data_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, 1);
[GT4aINT,IND4INT]=GjFULL(N, S, Ljjs_sjk3D, alpha_data_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, 0);

%=== GT4 - modified alphas ==============
delta_sjk3D=zeros(S,N,S);	
eta_sjk3D=zeros(S,N,S);
[GT4bLAB,IND4LAB]=GjFULL(N, S, Ljjs_sjk3D, alpha_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, 1);
[GT4bINT,IND4INT]=GjFULL(N, S, Ljjs_sjk3D, alpha_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, 0);

%=== GT7,8 - A1 ===========================
delta_sjk3D=ones(S,N,S);    delta_sjk3D(16:end,:,:)=0;

eta=0;                      eta_sjk3D=eta*ones(S,N,S);
[GT7A1_00_LAB,IND7A1_00_LAB]=GjFULL(N, S, Ljjs_sjk3D, alpha_tilde_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rhoj_sjk3D, 1);

eta=0.65;                      eta_sjk3D=eta*ones(S,N,S);
[GT8A1_05_LAB,IND8A1_05_LAB]=GjFULL(N, S, Ljjs_sjk3D, alpha_tilde_sjk3D, delta_sjk3D, epsilon_sjk3D, eta_sjk3D, betajs_sjk3D, vj_sjk3D, rjs_sjk3D, ejs_sjk3D, rho1_sjk3D, 1);


%=========================== SAVE THE SOLUTION ============================
GT_IND_ALL=	[GT1,GT2,GT3A,...
		GT4aLAB,GT4bLAB,...
		GT7A1_00_LAB,GT8A1_05_LAB];

dlmwrite('Table_1.csv', GT_IND_ALL);
