%==========================================================================
% Step 10: this file computes results reported in Table 2
%==========================================================================
clear all;

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                             Column 1 (3_1)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ------------- Load the zero-deficit data (see Step_03, ..._04 for details)
load Step_04_DATA_D0_PC_extd.mat;
Dj3D=Dj_new3D;      %Lijs3D=Lijs_new3D;
yis3D=yis_new3D;    Yi3D=Yi_new3D;      Yis3D=Yis_new3D;
Xijs3D=Xijs_new3D;

% ------------- Aggregate all sectors into: S=35 --> S=1
S=1;
Yi3D=Yi3D(:,:,1);       Dj3D=Dj3D(:,:,1);
Xij2D=sum(Xijs3D,3);    Xj2D=repmat(sum(Xij2D,1),[N 1]);    Lijs3D=Xij2D./Xj2D;
betajs3D=ones(N,N,S);   epsilon_s3D=5*ones(N,N,S);          sigma_s3D=epsilon_s3D+1;
consjs3D=ones(N,N,S);

% ------------- Set other parameters
% Initial and new tariffs (0% and 40% for US only)
tijs3D=zeros(N,N,S);
t_p=0.4; tijs_p3D=zeros(N,N,S); tijs_p3D(:,33,:)=t_p;   tijs_p3D(33,33,:)=0;

% Changes in transportation costs
tau_h=1;    tauij_h2D=tau_h*ones(N)+(1-tau_h)*eye(N);   tauijs_h3D=repmat(tauij_h2D,[1 1 S]);

% Other parameters
Dj_h3D=zeros(N,N,S);
X0=ones(N,1);
mu=1;

% ------------- Compute a new equilibrium for the system
syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
[x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
max(abs(fval_fsolve))  % check the accuracy of solution
wi_h=abs(x_fsolve((end-N+1):end,1));
wi_h3D=repmat(wi_h,[1 N S]);
[wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
kj_h=Ej_h./wj_h;
Pj_h=1./Pj_h;
RESULT=[wj_h, kj_h, Pj_h, Cj_h];
RESULT_SAVE_1=RESULT(:,4);
clearvars -except RESULT_SAVE_1


%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                             Column 2 (3_4)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ------------- Load the zero-deficit data (see Step_03, ..._04 for details)
load Step_04_DATA_D0_PC_extd.mat;
Dj3D=Dj_new3D;      Lijs3D=Lijs_new3D;
yis3D=yis_new3D;    Yi3D=Yi_new3D;      Yis3D=Yis_new3D;
Xijs3D=Xijs_new3D;

% ------------- Set other parameters
% Initial and new tariffs (0% and 40% for US only)
tijs3D=zeros(N,N,S);
t_p=0.4; tijs_p3D=zeros(N,N,S); tijs_p3D(:,33,:)=t_p;   tijs_p3D(33,33,:)=0;
% Changes in transportation costs
tau_h=1;    tauij_h2D=tau_h*ones(N)+(1-tau_h)*eye(N);   tauijs_h3D=repmat(tauij_h2D,[1 1 S]);
% Other parameters
Dj_h3D=zeros(N,N,S);
X0=ones(N,1);
mu=1;

% ------------- Compute a new equilibrium for the system
syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
[x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
max(abs(fval_fsolve))  % check the accuracy of solution
wi_h=abs(x_fsolve((end-N+1):end,1));
wi_h3D=repmat(wi_h,[1 N S]);
[wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
kj_h=Ej_h./wj_h;
Pj_h=1./Pj_h;
RESULT=[wj_h, kj_h, Pj_h, Cj_h];
RESULT_SAVE_2=RESULT(:,4);
clearvars -except RESULT_SAVE_1 RESULT_SAVE_2


%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                             Column 3 (3_3)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ------------- Load the zero-deficit data
load Step_04_DATA_D0_PC.mat
Dj3D=Dj_new3D;
Lijs3D=Lijs_new3D;
Yi3D=Yi_new3D;
yis3D=yis_new3D;

% ------------- Set other parameters
tauijs_h3D=ones(N,N,S);
tijs3D=zeros(N,N,S);
tijs_p3D=zeros(N,N,S);
Dj_h3D=ones(N,N,S);    
X0=ones(N,1);
mu=1;

% ------------- Compute a new equilibrium for the system
options = optimset('Display','iter','Algorithm','trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100000,'TolFun',1e-10,'TolX',1e-10);
NN=1000;
tus=0.4;    
C_h=zeros(N,NN);
w_h=zeros(N,NN);
k_h=zeros(N,NN);
P_h=zeros(N,NN);

    for i=1:NN  % loop for simulations
        tp=tus*(1+0.5*(-1+2*round(rand(S,1))));
        tp3D=repmat(reshape(tp,1,1,S),[N 1 1]);
        tijs_p3D(:,33,:)=tp3D;   tijs_p3D(33,33,:)=0;
        syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
        [x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
        max(abs(fval_fsolve))  % check the accuracy of solution
        wi_h=abs(x_fsolve((end-N+1):end,1));
        wi_h3D=repmat(wi_h,[1 N S]);
        [wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
        kj_h=Ej_h./wj_h;
        Pj_h=1./Pj_h;
        C_h(:,i)=Cj_h;
        w_h(:,i)=wj_h;
        k_h(:,i)=kj_h;
        P_h(:,i)=Pj_h;
    end

C_h_geom=(prod(C_h,2)).^(1/NN);    % Cus1^
w_h_geom=(prod(w_h,2)).^(1/NN);
k_h_geom=(prod(k_h,2)).^(1/NN);
P_h_geom=(prod(P_h,2)).^(1/NN);
C_h_avg=(mean(C_h,2));    % Cus1^
w_h_avg=(mean(w_h,2));
k_h_avg=(mean(k_h,2));
P_h_avg=(mean(P_h,2));

RESULT_SAVE_3=C_h_geom;
clearvars -except  RESULT_SAVE_1 RESULT_SAVE_2 RESULT_SAVE_3


%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                  Column 4 (PC_US-case: 1) data w/ D=0, 2) solve )
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%<PART1 -- convert the inital model to the zero trade deficit ones>
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_01_WIOD_AGG_with_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
consjs3D=betajs3D;
betajs3D=ejs3D;
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=alpha_tilde_sj3D.*ejk_sjk3D;
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         zeros(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      zeros(N,N,S);
eta_s3D=        zeros(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
%matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
%matlabpool close;
x_fsolve=(x_fsolve).^2;
max(abs(fval_fsolve))

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_PC_D0.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D


%<PART2 -- solve the model for shocks in US tariffs>
load Step_11_new_data_PC_D0.mat;   
%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- US 40%
t_p=                0.4;
tijs_p3D=           zeros(N,N,S);      
tijs_p3D(:,33,:)=   t_p;
tijs_p3D(33,33,:)=  0; 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
%matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
%matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
RESULT_SAVE_4=Cj;
clearvars -except  RESULT_SAVE_1 RESULT_SAVE_2 RESULT_SAVE_3 RESULT_SAVE_4





%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                  				Column 5 (3_2)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ------------- Load the zero-deficit data (see Step_03, ..._04 for details)
load Step_04_DATA_D0_PC_extd.mat;
Dj3D=Dj_new3D;      %Lijs3D=Lijs_new3D;
yis3D=yis_new3D;    Yi3D=Yi_new3D;      Yis3D=Yis_new3D;
Xijs3D=Xijs_new3D;

% ------------- Aggregate all sectors into: S=35 --> S=1
S=1;
Yi3D=Yi3D(:,:,1);       Dj3D=Dj3D(:,:,1);
Xij2D=sum(Xijs3D,3);    Xj2D=repmat(sum(Xij2D,1),[N 1]);    Lijs3D=Xij2D./Xj2D;
betajs3D=ones(N,N,S);   epsilon_s3D=5*ones(N,N,S);          sigma_s3D=epsilon_s3D+1;
consjs3D=ones(N,N,S);

% ------------- Set other parameters
% Initial and new tariffs (0% and 40% for all countries)
tijs3D=zeros(N,N,S);
t_p=0.4; tijs_p3D=repmat(t_p*(ones(N)-eye(N)),[1 1 S]);
% Changes in transportation costs
tau_h=1;    tauij_h2D=tau_h*ones(N)+(1-tau_h)*eye(N);   tauijs_h3D=repmat(tauij_h2D,[1 1 S]);
% Other parameters
Dj_h3D=zeros(N,N,S);
X0=ones(N,1);
mu=1;

% ------------- Compute a new equilibrium for the system
syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
[x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
max(abs(fval_fsolve))  % check the accuracy of solution
wi_h=abs(x_fsolve((end-N+1):end,1));
wi_h3D=repmat(wi_h,[1 N S]);
[wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
kj_h=Ej_h./wj_h;
Pj_h=1./Pj_h;
RESULT=[wj_h, kj_h, Pj_h, Cj_h];
RESULT_SAVE_5=RESULT(:,4);
clearvars -except  RESULT_SAVE_1 RESULT_SAVE_2 RESULT_SAVE_3 RESULT_SAVE_4 RESULT_SAVE_5



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                  				Column 6 (3_6)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ------------- Load the zero-deficit data (see Step_03, ..._04 for details)
load Step_04_DATA_D0_PC_extd.mat;
Dj3D=Dj_new3D;      Lijs3D=Lijs_new3D;
yis3D=yis_new3D;    Yi3D=Yi_new3D;      Yis3D=Yis_new3D;
Xijs3D=Xijs_new3D;

% ------------- Set other parameters
% Initial and new tariffs (0% and 40% for all countries)
tijs3D=zeros(N,N,S);
t_p=0.4; tijs_p3D=repmat(t_p*(ones(N)-eye(N)),[1 1 S]);
% Changes in transportation costs
tau_h=1;    tauij_h2D=tau_h*ones(N)+(1-tau_h)*eye(N);   tauijs_h3D=repmat(tauij_h2D,[1 1 S]);
% Other parameters
Dj_h3D=zeros(N,N,S);
X0=ones(N,1);
mu=1;

% ------------- Compute a new equilibrium for the system
syst=@(X) DEK_TRF_SYSTEM_N1(X, N ,S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg','MaxFunEvals',50000000,'MaxIter',100,'TolFun',1e-10,'TolX',1e-10); 
[x_fsolve,fval_fsolve]=fsolve(syst, X0, options);
max(abs(fval_fsolve))  % check the accuracy of solution
wi_h=abs(x_fsolve((end-N+1):end,1));
wi_h3D=repmat(wi_h,[1 N S]);
[wj_h, Pj_h, Ej_h, Cj_h]=DEK_WELFARE2_N1(wi_h3D, N , S, mu, Yi3D, Dj3D, Dj_h3D, betajs3D, consjs3D, sigma_s3D, tijs3D, tijs_p3D, tauijs_h3D, Lijs3D);
kj_h=Ej_h./wj_h;
Pj_h=1./Pj_h;
RESULT=[wj_h, kj_h, Pj_h, Cj_h];
RESULT_SAVE_6=RESULT(:,4);
clearvars -except  RESULT_SAVE_1 RESULT_SAVE_2 RESULT_SAVE_3 RESULT_SAVE_4 RESULT_SAVE_5 RESULT_SAVE_6



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% 			Column 7 (PC_WORLD-case: 1) data w/ D=0, 2) solve )
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% <Part 2 -- solve the model for changes in world tariffs>
% <Part 1 is omitted since we can used the already modified data from Column 4>
load Step_11_new_data_PC_D0.mat; 

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
%matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
%matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

RESULT_SAVE_7=Cj;

OUTPUT=[RESULT_SAVE_1, RESULT_SAVE_2, RESULT_SAVE_3, RESULT_SAVE_4, RESULT_SAVE_5, RESULT_SAVE_6, RESULT_SAVE_7]

dlmwrite('Table_2.csv', OUTPUT);


