%==========================================================================
% Step 11: this step the welfare implications of world tariff changes
% for an aggregated 10x16 data set
%==========================================================================
clear all;

result=[];

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 1: no intermetiates, perfect competition
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_no_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=zeros(S,N,S);
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      zeros(N,N,S);
eta_s3D=        zeros(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_PC_D0_no_INT.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_PC_D0_no_INT.mat; 

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 2: no intermetiates, Krugman setting
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_no_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=zeros(S,N,S);
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      ones(N,N,S);    delta_s3D(:,:,[16])=0;
eta_s3D=        zeros(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_KRG_D0_no_INT.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_KRG_D0_no_INT.mat;

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 3: no intermetiates, Melitz setting
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_no_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=zeros(S,N,S);
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      ones(N,N,S);    delta_s3D(:,:,[16])=0;
eta_s3D=        0.65*ones(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_MLZ_D0_no_INT.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_MLZ_D0_no_INT.mat;

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 4: with intermetiates, perfect competition
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_with_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
consjs3D=betajs3D;
betajs3D=ejs3D;
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=alpha_tilde_sj3D.*ejk_sjk3D;
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      zeros(N,N,S);
eta_s3D=        zeros(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_PC_D0.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_PC_D0.mat; 

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 5: Krugman setting
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_with_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
consjs3D=betajs3D;
betajs3D=ejs3D;
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=alpha_tilde_sj3D.*ejk_sjk3D;
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      ones(N,N,S);    delta_s3D(:,:,[16])=0;
eta_s3D=        zeros(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_KRG_D0.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_KRG_D0.mat;

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%            Column 6: Melitz setting
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_02_WIOD_AGG_10x16_with_INT.mat
% Adjust alphas as  (alpha_new_j,ks=alpha_j,s*e_j,k)
Xj3D=repmat(sum(Xjs3D,3),[1 1 S]);
ejs3D=Xjs3D./Xj3D;  % e_j,s in (i,j,s)
consjs3D=betajs3D;
betajs3D=ejs3D;
ejk_sjk3D=repmat(ejs3D(1,:,:),[S 1 1]);  %e_j,k in (s,j,k)
alpha_tilde_sjk3D=alpha_tilde_sj3D.*ejk_sjk3D;
alpha_tilde_sj3D=repmat(sum(alpha_tilde_sjk3D,3),[1 1 S]);   

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs
t_p=            0;  
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         0*ones(N,N,S);

%============================ SET PARAMETERS ==============================
delta_s3D=      ones(N,N,S);    delta_s3D(:,:,[16])=0;
eta_s3D=        0.65*ones(N,N,S);
mu=             1;
LABOR=          0;    % does not really matter for delta=0

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
sigma_s3D=      1+epsilon_s3D./(1+eta_s3D);
theta_s3D=      epsilon_s3D;
yis3D=          Yis3D./Yi3D;
ysi3D=          permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=          ysi3D(:,:,1);
ysjk3D=         repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=     tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm','trust-region-dogleg','Jacobian','on','MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(syst(x_fsolve)))
x_fsolve=(x_fsolve).^2;

%==================== COMPUTE THE NEW DATA (with D=0) =====================
[Dj3D, Lijs3D, Xijs3D, Xjs3D, Yi3D, Yis3D, Yj3D, yis3D, Ris3D, Ri3D, Rj3D]=...
MLZ_NEW_DATA(x_fsolve, N , S, mu, Xijs3D, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);

%=========================== SAVE THE SOLUTION ============================
save Step_11_new_data_10x16_MLZ_D0.mat N S delta_s3D eta_s3D mu LABOR Dj3D Xijs3D Xjs3D Ris3D Ri3D Rj3D...
    Lijs3D Yi3D Yis3D Yj3D yis3D alpha_tilde_sj3D alpha_tilde_sjk3D betajs3D consjs3D epsilon_s3D sigma_s3D theta_s3D

%============================ READ THE DATA ===============================
% Load data from Step_01_..._MC_INT.m. All variables in the loaded data are 
% "cubes" NxNxS: (i,j,s), except alpha_tilde_sjk3D, which is (SxNxS)
load Step_11_new_data_10x16_MLZ_D0.mat;

%============================== SET SHOCKS ================================
% Initial tariff
t=              0;    
tij2D=          t*(ones(N)-eye(N)); % "0" on diagonal and "t" -- off-diag
tijs3D=         repmat(tij2D,[1 1 S]);
% New tariffs -- 40%
t_p=            0.4;      
tij_p2D=        t_p*(ones(N)-eye(N)); % "0" on diagonal and "t_p" -- off-diag
tijs_p3D=       repmat(tij_p2D,[1 1 S]); 
% Changes in transportation costs
tau_h=          1;
tauij_h2D=      tau_h*(ones(N)-eye(N))+eye(N);   % "1" on diagonal, "tau^" -- of-diag
tauijs_h3D=     repmat(tauij_h2D,[1 1 S]);
% Changes in trade deficits
Dj_h3D=         ones(N,N,S);

%============================ SET PARAMETERS ==============================
% <ALL THE NEEDED PARAMETERS ARE UPLOADED WITH THE DATA FILE ..._D0.MAT>

%========== COMPUTE AUXILIARY VARIABLES (NOT DEPENDENT ON .^s) ============
ysi3D=permute(yis3D,[3 1 2]); % y_i,s in (s,i,j)
ysi2D=ysi3D(:,:,1);
ysjk3D=repmat(ysi2D,[1 1 S]);   % y_j,s in (s,j,k)
phiijs_h3D=tauijs_h3D.*(1+tijs_p3D)./(1+tijs3D);    % change in trade costs

%============================= SOLVE THE MODEL ============================
X0=ones(N*(2*S+1),1);   % initial value (using some randomization)
syst=@(X) MLZ_TRF_SYSTEM_MANY_ARGS_FIXED_COSTS(X, N , S, mu, Yi3D, Yj3D, yis3D, ysjk3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
dsyst=@(X) df(X, syst);
expsyst=@(X) deal(syst(X),dsyst(X));
matlabpool('open',12);
options=optimset('Display','iter','Algorithm', 'trust-region-dogleg', 'Jacobian','on', 'MaxFunEvals',50000000,'MaxIter',1000,'TolFun',1e-30,'TolX',1e-30); 
[x_fsolve,fval_fsolve]=fsolve(expsyst, X0, options);
matlabpool close;
max(abs(fval_fsolve))
x_fsolve=(x_fsolve).^2;

%====================== COMPUTE WELFARE IMPLICATIONS ======================
[Cj]=...
    MLZ_WELFARE_CORRECTED(x_fsolve, N , S, mu, Yi3D, Yj3D, ysjk3D, Ris3D, Dj3D, Dj_h3D,...
    alpha_tilde_sjk3D, betajs3D, consjs3D, epsilon_s3D, theta_s3D, eta_s3D, delta_s3D, sigma_s3D,...
    tijs3D, tijs_p3D, phiijs_h3D, Lijs3D, LABOR);
result=[result,Cj];
clearvars -except result



dlmwrite('Table_3.csv', result);

