%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% df(x, fun, h) -- compute the Jacobian of f(x) numerically.
%
%  INPUT:
%      x -- point at which the Jacobian should be evaluated
%
%    fun -- handle to a function computing values of f(x)
%
%  OPTIONAL INPUT:
%
%      h -- spacing used to compute the derivative
%
%  OUTPUT:
%
%      y -- Jacobian matrix
%
%  EXAMPLE:
%
%    df(1, @(x) sin(x));
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function y = df(x, fun, h)
y = zeros(length(x), length(x));
xh = x;

if (nargin < 2)
	error('At least two inputs required');
elseif (nargin < 3)
	h = 1e-3;
end;

parfor i = 1:1:length(x)
  xh = x;
  xh(i) = x(i) + h;
  fn = fun(xh);

  xh(i) = x(i) - h;
  fp = fun(xh);

  y(:, i) = (fn - fp) ./ (2.0 * h);
end;
